from django.shortcuts import render, redirect
from django.http import JsonResponse
from django.conf import settings
import time
import os
import rust_crud_api # Custom Rust Pyo3 Library 🦀

db_url = settings.DATABASE_URL

def group_list_view(request):
    """
    List all groups.
    """
    db_url = settings.DATABASE_URL
    context = {}
    try:
        groups = rust_crud_api.get_all_groups(db_url)
        context['groups'] = groups
    except Exception as e:
        context['error'] = f"An error occurred: {e}"
    return render(request, 'myapp/group_list.html', context)

def group_create_view(request):
    """
    Create a new group.
    """
    db_url = settings.DATABASE_URL
    context = {}
    if request.method == 'POST':
        group_name = request.POST.get('name', '').strip()
        if not group_name:
            context['error'] = "Group name is required."
            return render(request, 'myapp/group_create.html', context)
        try:
            rust_crud_api.create_group(db_url, group_name)
            return redirect('group_list')
        except Exception as e:
            context['error'] = f"An error occurred: {e}"
            return render(request, 'myapp/group_create.html', context)
    return render(request, 'myapp/group_create.html', context)

def group_update_view(request, group_id):
    """
    Update an existing group's name.
    """
    db_url = settings.DATABASE_URL
    context = {}
    try:
        group = rust_crud_api.get_group(db_url, int(group_id))
        if group is None:
            context['error'] = "Group not found."
            return render(request, 'myapp/group_update.html', context)
    except Exception as e:
        context['error'] = f"Error retrieving group: {e}"
        return render(request, 'myapp/group_update.html', context)
    
    if request.method == 'POST':
        new_name = request.POST.get('name', '').strip()
        if not new_name:
            context['error'] = "New group name is required."
            context['group'] = group
            return render(request, 'myapp/group_update.html', context)
        try:
            rust_crud_api.update_group(db_url, int(group_id), new_name)
            return redirect('group_list')
        except Exception as e:
            context['error'] = f"Error updating group: {e}"
            context['group'] = group
            return render(request, 'myapp/group_update.html', context)
    
    context['group'] = group
    return render(request, 'myapp/group_update.html', context)

def group_delete_view(request, group_id):
    """
    Delete a group.
    """
    db_url = settings.DATABASE_URL
    context = {}
    if request.method == 'POST':
        try:
            success = rust_crud_api.delete_group(db_url, int(group_id))
            if success:
                return redirect('group_list')
            else:
                context['error'] = "Deletion failed."
        except Exception as e:
            context['error'] = f"Error deleting group: {e}"
    else:
        try:
            group = rust_crud_api.get_group(db_url, int(group_id))
            context['group'] = group
        except Exception as e:
            context['error'] = f"Error retrieving group: {e}"
    return render(request, 'myapp/group_delete.html', context)

def group_detail_view(request, group_id):
    db_url = settings.DATABASE_URL
    context = {}

    if request.method == 'POST':
        user_id = request.POST.get('user_id')  # might be None or 'None'

        # Check for None *before* calling Rust
        if not user_id or user_id == 'None':
            context['error'] = "Invalid user_id: None"
            return render(request, 'myapp/group_detail.html', context)

        try:
            # Now we safely do int(user_id) because we checked it's not None
            result = rust_crud_api.add_user_to_group(db_url, int(group_id), int(user_id))
        except Exception as e:
            context['error'] = f"An error occurred: {e}"
            return render(request, 'myapp/group_detail.html', context)

    # Normal GET behavior...
    return render(request, 'myapp/group_detail.html', context)




def group_search_view(request):
    """
    Handles searching for groups using Rust.
    """
    db_url = settings.DATABASE_URL  
    query = request .GET.get("q", "").strip()  
    groups = [] 
    if query:
        try:
            groups = rust_crud_api.search_groups(db_url, query) 
        except Exception as e:
            return render(request, "group_search.html", {"error": str(e), "query": query})

    return render(request, "group_search.html", {"groups": groups, "query": query})
