use pyo3::prelude::*;
use pyo3::exceptions::PyRuntimeError;
use jsonwebtoken::{encode, decode, Header, Validation, EncodingKey, DecodingKey};
use serde::{Serialize, Deserialize};
use pyo3::types::PyDict;

#[derive(Debug, Serialize, Deserialize)]
struct Claims {
    sub: String,
    exp: usize,
}

#[pyfunction]
pub fn generate_jwt(user_email: String, secret: String, exp: usize) -> PyResult<String> {
    let claims = Claims { sub: user_email, exp };
    encode(&Header::default(), &claims, &EncodingKey::from_secret(secret.as_ref()))
        .map_err(|e| PyRuntimeError::new_err(e.to_string()))
}

#[pyfunction]
pub fn verify_jwt(token: String, secret: String) -> PyResult<PyObject> {
    let token_data = decode::<Claims>(
        &token,
        &DecodingKey::from_secret(secret.as_ref()),
        &Validation::default(),
    ).map_err(|e| PyRuntimeError::new_err(e.to_string()))?;

    let claims = token_data.claims; // Move claims inside the function scope

    Python::with_gil(|py| {
        let dict = PyDict::new(py);
        dict.set_item("sub", claims.sub)?;
        dict.set_item("exp", claims.exp)?;
        Ok(dict.to_object(py))
    })
}


